@@ -21,7 +21,7 @@ import (
 // Client is used to store the pool of db connection.
 type Client struct {
 	db                *sqlx.DB
-	driver            string
+	driver, schema    string
 	paginationManager *pagination.Manager
 	limit             int
 }
@@ -44,6 +44,21 @@ func New(opts command.Options) (*Client, error) {
 		limit:  opts.Limit,
 	}
 
+	if opts.Schema == "" {
+		c.schema = "public"
+	} else {
+		c.schema = opts.Schema
+	}
+
+	switch c.driver {
+	case "postgres":
+		fallthrough
+	case "postgresql":
+		if _, err = db.Exec(fmt.Sprintf("set search_path='%s'", c.schema)); err != nil {
+			return nil, err
+		}
+	}
+
 	pm, err := pagination.New(c.limit, 0, "")
 	if err != nil {
 		return nil, err
@@ -185,22 +200,28 @@ func (c *Client) TotalPages() int {
 
 // ShowTables list all the tables in the database on the tables panel.
 func (c *Client) ShowTables() ([]string, error) {
-	var query string
+	var (
+		query string
+		err   error
+		args  []interface{}
+	)
+
 	tables := make([]string, 0)
 
 	switch c.driver {
 	case "postgres":
 		fallthrough
 	case "postgresql":
-		query = `
-		SELECT
-			table_name
-		FROM
-			information_schema.tables
-		WHERE
-			table_schema = 'public'
-		ORDER BY
-			table_name;`
+		psql := sq.StatementBuilder.PlaceholderFormat(sq.Dollar)
+		query, args, err = psql.Select("table_name").
+			From("information_schema.tables").
+			Where(sq.Eq{"table_schema": c.schema}).
+			OrderBy("table_name").
+			ToSql()
+		if err != nil {
+			return nil, err
+		}
+
 	case "mysql":
 		query = "SHOW TABLES;"
 	case "sqlite3":
@@ -214,7 +235,7 @@ func (c *Client) ShowTables() ([]string, error) {
 			name NOT LIKE 'sqlite_%';`
 	}
 
-	rows, err := c.db.Queryx(query)
+	rows, err := c.db.Queryx(query, args...)
 	if err != nil {
 		return nil, err
 	}
@@ -301,7 +322,7 @@ func (c *Client) tableContent(tableName string) ([][]string, []string, error) {
 	var query string
 
 	if c.driver == "postgres" || c.driver == "postgresql" {
-		query = fmt.Sprintf("SELECT * FROM public.%s LIMIT %d OFFSET %d;", tableName, c.paginationManager.Limit(), c.paginationManager.Offset())
+		query = fmt.Sprintf("SELECT * FROM %q LIMIT %d OFFSET %d;", tableName, c.paginationManager.Limit(), c.paginationManager.Offset())
 	} else {
 		query = fmt.Sprintf("SELECT * FROM %s LIMIT %d OFFSET %d;", tableName, c.paginationManager.Limit(), c.paginationManager.Offset())
 	}
@@ -317,7 +338,7 @@ func (c *Client) tableCount(tableName string) (int, error) {
 	)
 
 	if c.driver == "postgres" || c.driver == "postgresql" {
-		query = fmt.Sprintf("SELECT COUNT(*) FROM public.%s;", tableName)
+		query = fmt.Sprintf("SELECT COUNT(*) FROM %q;", tableName)
 	} else {
 		query = fmt.Sprintf("SELECT COUNT(*) FROM %s;", tableName)
 	}
@@ -337,33 +358,42 @@ func (c *Client) tableStructure(tableName string) ([][]string, []string, error)
 	case "postgres":
 		fallthrough
 	case "postgresql":
-		query = `
-        SELECT
-			c.column_name,
-			c.is_nullable,
-			c.data_type,
-			c.character_maximum_length,
-			c.numeric_precision,
-			c.numeric_scale,
-			c.ordinal_position,
-			tc.constraint_type pkey
-		FROM
-			information_schema.columns c
-		LEFT JOIN
-			information_schema.constraint_column_usage AS ccu
-		ON
-			c.table_schema = ccu.table_schema
-			AND c.table_name = ccu.table_name
-			AND c.column_name = ccu.column_name
-		LEFT JOIN
-			information_schema.table_constraints AS tc
-		ON
-			ccu.constraint_schema = tc.constraint_schema
-			and ccu.constraint_name = tc.constraint_name
-		WHERE
-			c.table_schema = 'public'
-			AND c.table_name = $1;`
-		return c.Query(query, tableName)
+		psql := sq.StatementBuilder.PlaceholderFormat(sq.Dollar)
+
+		query, args, err := psql.Select(
+			"c.column_name",
+			"c.is_nullable",
+			"c.data_type",
+			"c.character_maximum_length",
+			"c.numeric_precision",
+			"c.numeric_scale",
+			"c.ordinal_position",
+			"tc.constraint_type AS pkey",
+		).
+			From("information_schema.columns AS c").
+			LeftJoin(
+				`information_schema.constraint_column_usage AS ccu
+					ON c.table_schema = ccu.table_schema
+						AND c.table_name = ccu.table_name
+						AND c.column_name = ccu.column_name`,
+			).
+			LeftJoin(
+				`information_schema.table_constraints AS tc
+					ON ccu.constraint_schema = tc.constraint_schema
+						AND ccu.constraint_name = tc.constraint_name`,
+			).
+			Where(
+				sq.And{
+					sq.Eq{"c.table_schema": c.schema},
+					sq.Eq{"c.table_name": tableName},
+				},
+			).
+			ToSql()
+		if err != nil {
+			return nil, nil, err
+		}
+
+		return c.Query(query, args...)
 	case "mysql":
 		query = fmt.Sprintf("DESCRIBE %s;", tableName)
 		return c.Query(query)
@@ -402,7 +432,7 @@ func (c *Client) constraints(tableName string) ([][]string, []string, error) {
 	case "postgres":
 		fallthrough
 	case "postgresql":
-		query = query.Where("tc.table_schema = 'public'")
+		query = query.Where(fmt.Sprintf("tc.table_schema = '%s'", c.schema))
 		query = query.PlaceholderFormat(sq.Dollar)
 	}
 
