@@ -12,6 +12,8 @@ type Options struct {
 	Pass   string
 	DBName string
 	SSL    string
+	// PostgreSQL only.
+	Schema string
 	Limit  int
 }
 
@@ -46,5 +48,9 @@ func SetDefault(opts Options) Options {
 		opts.Port = os.Getenv("DB_PORT")
 	}
 
+	if opts.Schema == "" {
+		opts.Schema = os.Getenv("DB_SCHEMA")
+	}
+
 	return opts
 }
